import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { map } from 'rxjs/operators';
import { Qualification } from '../qualification/Qualification';
import { Employee } from '../employee/Employee';

@Injectable({
  providedIn: 'root',
})
export default class QualificationService {
  private static readonly BASE_URL = '/backend';

  private readonly apiUrl = `${QualificationService.BASE_URL}/qualifications`;

  constructor(private http: HttpClient) {}

  getAll(): Observable<Qualification[]> {
    return this.http
      .get<Qualification[]>(this.apiUrl)
      .pipe(
        map((qualifications) => qualifications.sort((a, b) => a.id - b.id)),
      );
  }

  getById(id: number): Observable<Qualification> {
    return this.http.get<Qualification>(`${this.apiUrl}/${id}`);
  }

  create(qualification: Omit<Qualification, 'id'>): Observable<Qualification> {
    return this.http.post<Qualification>(this.apiUrl, qualification);
  }

  update(
    id: number,
    qualification: Partial<Qualification>,
  ): Observable<Qualification> {
    return this.http.put<Qualification>(`${this.apiUrl}/${id}`, qualification);
  }

  delete(id: number): Observable<void> {
    return this.http.delete<void>(`${this.apiUrl}/${id}`);
  }

  findEmployees(id: number): Observable<Employee[]> {
    interface EmployeeResponse {
      employees: Employee[];
    }
    return this.http
      .get<EmployeeResponse>(`${this.apiUrl}/${id}/employees`)
      .pipe(map((response) => response.employees));
  }
}
